==> haskell-bytestring-progress-1.4-59-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-bytestring-progress.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 bytestring-progress
version:              1.4
visibility:           public
id:                   bytestring-progress-1.4-5eO8rI72yAgCNkcufVDY7A
key:                  bytestring-progress-1.4-5eO8rI72yAgCNkcufVDY7A
license:              BSD-3-Clause
maintainer:           Adam Wick <awick@uhsure.com>
author:               Adam Wick <awick@uhsure.com>
homepage:             http://github.com/acw/bytestring-progress
synopsis:             A library for tracking the consumption of a lazy ByteString
description:
    In some cases, it is useful to know how fast a ByteString is being
    consumed. Typically, this could be to report some measure of progress
    to a waiting user, but it could also be to perform some form of testing
    on input / consumption code.

category:             Control
abi:                  62a9beddf5d39e9d042ebd4614208b9a
exposed:              True
exposed-modules:
    Data.ByteString.Lazy.Progress System.ProgressBar.ByteString

import-dirs:          /usr/lib/ghc-9.2.8/site-local/bytestring-progress-1.4
library-dirs:         /usr/lib/ghc-9.2.8/site-local/bytestring-progress-1.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-bytestring-progress
hs-libraries:         HSbytestring-progress-1.4-5eO8rI72yAgCNkcufVDY7A
depends:
    base-4.16.4.0 bytestring-0.11.4.0
    terminal-progress-bar-0.4.2-GLswdkvmjBnBqzMYGkpoI8 text-1.2.5.0
    time-1.11.1.1

haddock-interfaces:
    /usr/share/doc/haskell-bytestring-progress/html/bytestring-progress.haddock

haddock-html:         /usr/share/doc/haskell-bytestring-progress/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-bytestring-progress-1.4-60-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-bytestring-progress.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 bytestring-progress
version:              1.4
visibility:           public
id:                   bytestring-progress-1.4-JtTSizhbuDIKB9u0301zmq
key:                  bytestring-progress-1.4-JtTSizhbuDIKB9u0301zmq
license:              BSD-3-Clause
maintainer:           Adam Wick <awick@uhsure.com>
author:               Adam Wick <awick@uhsure.com>
homepage:             http://github.com/acw/bytestring-progress
synopsis:             A library for tracking the consumption of a lazy ByteString
description:
    In some cases, it is useful to know how fast a ByteString is being
    consumed. Typically, this could be to report some measure of progress
    to a waiting user, but it could also be to perform some form of testing
    on input / consumption code.

category:             Control
abi:                  687e97e6efee8b6ae5cd42a515695dc6
exposed:              True
exposed-modules:
    Data.ByteString.Lazy.Progress System.ProgressBar.ByteString

import-dirs:          /usr/lib/ghc-9.2.8/site-local/bytestring-progress-1.4
library-dirs:         /usr/lib/ghc-9.2.8/site-local/bytestring-progress-1.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-bytestring-progress
hs-libraries:         HSbytestring-progress-1.4-JtTSizhbuDIKB9u0301zmq
depends:
    base-4.16.4.0 bytestring-0.11.4.0
    terminal-progress-bar-0.4.2-7LS0DwpWuYm92BhRInap4p text-1.2.5.0
    time-1.11.1.1

haddock-interfaces:
    /usr/share/doc/haskell-bytestring-progress/html/bytestring-progress.haddock

haddock-html:         /usr/share/doc/haskell-bytestring-progress/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
